@@ -154,6 +154,9 @@ arv_pixel_format_get_type (void)
 			{ ARV_PIXEL_FORMAT_MONO_12_PACKED,
 			  "ARV_PIXEL_FORMAT_MONO_12_PACKED",
 			  "mono-12-packed" },
+			{ ARV_PIXEL_FORMAT_MONO_14,
+			  "ARV_PIXEL_FORMAT_MONO_14",
+			  "mono-14" },
 			{ ARV_PIXEL_FORMAT_MONO_16,
 			  "ARV_PIXEL_FORMAT_MONO_16",
 			  "mono-16" },
@@ -193,6 +196,9 @@ arv_pixel_format_get_type (void)
 			{ ARV_PIXEL_FORMAT_BAYER_BG_12,
 			  "ARV_PIXEL_FORMAT_BAYER_BG_12",
 			  "bayer-bg-12" },
+			{ ARV_PIXEL_FORMAT_BAYER_BG_12_PACKED,
+			  "ARV_PIXEL_FORMAT_BAYER_BG_12_PACKED",
+			  "bayer-bg-12-packed" },
 			{ ARV_PIXEL_FORMAT_RGB_8_PACKED,
 			  "ARV_PIXEL_FORMAT_RGB_8_PACKED",
 			  "rgb-8-packed" },
